<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans svn://trac.rezo.net/spip/branches/spip-2.1/ecrire/lang/
if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'Fran&ccedil;ais [fr]',
'0_liste' => 'spip-dev@rezo.net',
'0_mainteneur' => 'spip-dev@rezo.net',

// A
'access_interface_graphique' => 'Retour &agrave; l\'interface graphique compl&egrave;te',
'access_mode_texte' => 'Afficher l\'interface textuelle simplifi&eacute;e',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Modifier cet article',
'admin_modifier_auteur' => 'Modifier cet auteur',
'admin_modifier_breve' => 'Modifier cette br&egrave;ve',
'admin_modifier_mot' => 'Modifier ce mot-cl&eacute;',
'admin_modifier_rubrique' => 'Modifier cette rubrique',
'admin_recalculer' => 'Recalculer cette page',
'afficher_trad' => 'afficher les traductions',
'alerte_maj_impossible' => '<b>Alerte&nbsp;!</b> La mise &agrave; jour de la base SQL vers la version @version@ est impossible, peut-&ecirc;tre &agrave; cause d\'un probl&egrave;me de droit de modification sur la base de donn&eacute;es. Veuillez contacter votre h&eacute;bergeur.',
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute;e par ailleurs. La valeur actuelle est&nbsp;:',
'analyse_xml' => 'Analyse XML',
'annuler' => 'Annuler',
'antispam_champ_vide' => 'Veuillez laisser ce champ vide&nbsp;:',
'articles_recents' => 'Articles les plus r&eacute;cents',
'avis_archive_incorrect' => 'le fichier archive n\'est pas un fichier SPIP',
'avis_archive_invalide' => 'le fichier archive n\'est pas valide',
'avis_attention' => 'ATTENTION&nbsp;!',
'avis_champ_incorrect_type_objet' => 'Nom de champ incorrect @name@ pour objet de type @type@',
'avis_colonne_inexistante' => 'La colonne @col@ n\'existe pas',
'avis_echec_syndication_01' => 'La syndication a &eacute;chou&eacute; : le backend indiqu&eacute; est ind&eacute;chiffrable ou ne propose aucun article.',
'avis_echec_syndication_02' => 'La syndication a &eacute;chou&eacute; : impossible d\'acc&eacute;der au backend de ce site.',
'avis_erreur' => 'Erreur: voir ci-dessous',
'avis_erreur_connexion' => 'Erreur de connexion',
'avis_erreur_cookie' => 'probl&egrave;me de cookie',
'avis_erreur_fonction_contexte' => 'Erreur de programmation. Cette fonction ne doit pas &ecirc;tre appel&eacute;e dans ce contexte.',
'avis_erreur_mysql' => 'Erreur SQL',
'avis_erreur_sauvegarde' => 'Erreur dans la sauvegarde (@type@ @id_objet@) !',
'avis_erreur_visiteur' => 'Probl&egrave;me d\'acc&egrave;s &agrave; l\'espace priv&eacute;',

// B
'barre_a_accent_grave' => 'Ins&eacute;rer un A accent grave majuscule',
'barre_aide' => 'Utilisez les raccourcis typographiques pour enrichir votre mise en page',
'barre_e_accent_aigu' => 'Ins&eacute;rer un E accent aigu majuscule',
'barre_eo' => 'Ins&eacute;rer un E dans l\'O',
'barre_eo_maj' => 'Ins&eacute;rer un E dans l\'O majuscule',
'barre_euro' => 'Ins&eacute;rer le symbole &euro;',
'barre_gras' => 'Mettre en {{gras}}',
'barre_guillemets' => 'Entourer de &laquo; guillemets &raquo;',
'barre_guillemets_simples' => 'Entourer de &ldquo;guillemets de second niveau&rdquo;',
'barre_intertitre' => 'Transformer en {{{intertitre}}}',
'barre_italic' => 'Mettre en {italique}',
'barre_lien' => 'Transformer en [lien hypertexte->http://...]',
'barre_lien_input' => 'Veuillez indiquer l\'adresse de votre lien (vous pouvez indiquer une adresse Web sous la forme http://www.monsite/com ou simplement indiquer le num&eacute;ro d\'un article de ce site.',
'barre_note' => 'Transformer en [[Note de bas de page]]',
'barre_paragraphe' => 'Cr&#233;er un paragraphe',
'barre_quote' => '<quote>Citer un message</quote>',
'bouton_ajouter_document' => 'Ajouter un document',
'bouton_ajouter_image' => 'Ajouter une image',
'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document',
'bouton_changer' => 'Changer',
'bouton_chercher' => 'Chercher',
'bouton_choisir' => 'Choisir',
'bouton_download' => 'T&eacute;l&eacute;charger',
'bouton_enregistrer' => 'Enregistrer',
'bouton_radio_desactiver_messagerie_interne' => 'D&eacute;sactiver la messagerie interne',
'bouton_radio_envoi_annonces' => 'Envoyer les annonces &eacute;ditoriales',
'bouton_radio_non_envoi_annonces' => 'Ne pas envoyer d\'annonces',
'bouton_radio_non_envoi_liste_nouveautes' => 'Ne pas envoyer  la liste des nouveaut&eacute;s',
'bouton_recharger_page' => 'recharger cette page',
'bouton_telecharger' => 'T&eacute;l&eacute;charger',
'bouton_valider' => 'Valider',

// C
'cal_apresmidi' => 'apr&egrave;s-midi',
'cal_jour_entier' => 'jour entier',
'cal_matin' => 'matin',
'cal_par_jour' => 'calendrier par jour',
'cal_par_mois' => 'calendrier par mois',
'cal_par_semaine' => 'calendrier par semaine',
'choix_couleur_interface' => 'couleur ',
'choix_interface' => 'choix  de l\'interface',
'colonne' => 'Colonne',
'confirm_changer_statut' => 'Attention, vous avez demand&eacute; &agrave; changer le statut de cet &eacute;l&eacute;ment. Souhaitez-vous continuer?',
'correcte' => 'correcte', # chaine utilis&eacute;e dans le debugueur : "validation .. impossible" ou "validation .. correcte"

// D
'date_aujourdhui' => 'aujourd\'hui',
'date_avant_jc' => 'av. J.C.',
'date_dans' => 'dans @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'demain',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ &agrave; @heure@',
'date_fmt_jour_mois' => '@jour@ @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => 'le @nomjour@ @date@',
'date_heures' => 'heures',
'date_hier' => 'hier',
'date_il_y_a' => 'il y a @delai@',
'date_jnum1' => '1er',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'dimanche',
'date_jour_1_abbr' => 'dim.',
'date_jour_1_initiale' => 'd.',
'date_jour_2' => 'lundi',
'date_jour_2_abbr' => 'lun.',
'date_jour_2_initiale' => 'l.',
'date_jour_3' => 'mardi',
'date_jour_3_abbr' => 'mar.',
'date_jour_3_initiale' => 'm.',
'date_jour_4' => 'mercredi',
'date_jour_4_abbr' => 'mer.',
'date_jour_4_initiale' => 'm.',
'date_jour_5' => 'jeudi',
'date_jour_5_abbr' => 'jeu.',
'date_jour_5_initiale' => 'j.',
'date_jour_6' => 'vendredi',
'date_jour_6_abbr' => 'ven.',
'date_jour_6_initiale' => 'v.',
'date_jour_7' => 'samedi',
'date_jour_7_abbr' => 'sam.',
'date_jour_7_initiale' => 's.',
'date_jours' => 'jours',
'date_minutes' => 'minutes',
'date_mois' => 'mois',
'date_mois_1' => 'janvier',
'date_mois_10' => 'octobre',
'date_mois_11' => 'novembre',
'date_mois_12' => 'd&eacute;cembre',
'date_mois_2' => 'f&eacute;vrier',
'date_mois_3' => 'mars',
'date_mois_4' => 'avril',
'date_mois_5' => 'mai',
'date_mois_6' => 'juin',
'date_mois_7' => 'juillet',
'date_mois_8' => 'ao&ucirc;t',
'date_mois_9' => 'septembre',
'date_saison_1' => 'hiver',
'date_saison_2' => 'printemps',
'date_saison_3' => '&eacute;t&eacute;',
'date_saison_4' => 'automne',
'date_secondes' => 'secondes',
'date_semaines' => 'semaines',
'date_un_mois' => 'mois',
'date_une_heure' => 'heure',
'date_une_minute' => 'minute',
'date_une_seconde' => 'seconde',
'date_une_semaine' => 'semaine',
'dirs_commencer' => ' afin de commencer r&eacute;ellement l\'installation',
'dirs_preliminaire' => 'Pr&eacute;liminaire : <b>R&eacute;gler les droits d\'acc&egrave;s</b>',
'dirs_probleme_droits' => 'Probl&egrave;me de droits d\'acc&egrave;s',
'dirs_repertoires_absents' => '<p><b>Les r&eacute;pertoires suivants n\'ont pas &eacute;t&eacute; trouv&eacute;s&nbsp;:</b></p><ul>@bad_dirs@</ul>
  <p>Il est probable que cela soit d&ucirc; &agrave; un probl&egrave;me de mauvaise mise en majuscules ou minuscules.
  V&eacute;rifiez que les minuscules et majuscules de ces r&eacute;pertoires concordent bien avec ce qui est affich&eacute;
  ci-dessus ; si ce n\'est pas le cas, renommez les r&eacute;pertoires avec votre logiciel FTP de fa&ccedil;on &agrave; corriger l\'erreur.</p>
  <p>Une fois cette manipulation effectu&eacute;e, vous pourrez ',
'dirs_repertoires_suivants' => '<p><b>Les r&eacute;pertoires suivants ne sont pas accessibles en &eacute;criture&nbsp;:</b></p> <ul>@bad_dirs@</ul>
  <p>Pour y rem&eacute;dier, utilisez votre client FTP afin de r&eacute;gler les droits d\'acc&egrave;s de chacun
  de ces r&eacute;pertoires. La proc&eacute;dure est expliqu&eacute;e en d&eacute;tail dans le guide d\'installation.</p>
  <p>Une fois cette manipulation effectu&eacute;e, vous pourrez ',
'double_occurrence' => 'Double occurrence de @balise@',

// E
'en_cours' => 'en cours',
'entree_dimensions' => 'Dimensions&nbsp;:',
'entree_titre_document' => 'Titre du document&nbsp;:',
'entree_titre_image' => 'Titre de l\'image&nbsp;:',
'envoi_via_le_site' => 'Envoi via le site',
'erreur' => 'Erreur',
'erreur_balise_non_fermee' => 'derni&egrave;re balise non referm&eacute;e :',
'erreur_texte' => 'erreur(s)',
'etape' => '&Eacute;tape',

// F
'fichier_introuvable' => 'Fichier @fichier@ introuvable',
'form_auteur_confirmation' => 'Confirmez votre adresse email',
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.',
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.',
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
',
'form_deja_inscrit' => 'Vous &ecirc;tes d&eacute;j&agrave; inscrit.',
'form_email_non_valide' => 'Votre adresse email n\'est pas valide.',
'form_forum_access_refuse' => 'Vous n\'avez plus acc&egrave;s &agrave; ce site.',
'form_forum_bonjour' => 'Bonjour @nom@,',
'form_forum_email_deja_enregistre' => 'Cette adresse e-mail est d&eacute;j&agrave; enregistr&eacute;e, vous pouvez donc utiliser votre mot de passe habituel.',
'form_forum_identifiant_mail' => 'Votre nouvel identifiant vient de vous &ecirc;tre envoy&eacute; par email.',
'form_forum_identifiants' => 'Identifiants personnels',
'form_forum_indiquer_nom_email' => 'Indiquez ici votre nom et votre adresse email. Votre identifiant personnel vous parviendra rapidement, par courrier &eacute;lectronique.',
'form_forum_login' => 'login :',
'form_forum_message_auto' => '(ceci est un message automatique)',
'form_forum_pass' => 'mot de passe :',
'form_forum_probleme_mail' => 'Probl&egrave;me de mail&nbsp;: l\'identifiant ne peut pas &ecirc;tre envoy&eacute;.',
'form_forum_voici1' => 'Voici vos identifiants pour pouvoir participer &agrave; la vie
du site "@nom_site_spip@" (@adresse_site@) :',
'form_forum_voici2' => 'Voici vos identifiants pour proposer des articles sur
le site "@nom_site_spip@" (@adresse_login@) :',
'form_indiquer_email' => 'Veuillez indiquer votre adresse email.',
'form_indiquer_nom' => 'Veuillez indiquer votre nom.',
'form_indiquer_nom_site' => 'Veuillez indiquer le nom de votre site.',
'form_pet_adresse_site' => 'Adresse de votre site',
'form_pet_aucune_signature' => 'Aucune signature ne correspond &agrave; ce code...',
'form_pet_confirmation' => 'Veuillez confirmer votre signature :',
'form_pet_deja_enregistre' => 'Ce site est d&eacute;j&agrave; enregistr&eacute;',
'form_pet_deja_signe' => 'Vous avez d&eacute;j&agrave; sign&eacute; ce texte.',
'form_pet_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre signature.',
'form_pet_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; signer la p&eacute;tition :
@titre@.

Vous avez fourni les informations suivantes :
    Nom: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

IMPORTANT...
Pour valider votre signature, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera rejet&eacute;e) :

    @url@


Merci de votre participation
',
'form_pet_message_commentaire' => 'Un message, un commentaire&nbsp;?',
'form_pet_nom_site2' => 'Nom de votre site Web', # enlever le gras
'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.',
'form_pet_probleme_technique' => 'Probl&egrave;me technique, les signatures sont temporairement suspendues.',
'form_pet_signature_pasprise' => 'Votre signature n\'est pas prise en compte.',
'form_pet_signature_validee' => 'Votre signature est valid&eacute;e. Merci&nbsp;!',
'form_pet_site_deja_enregistre' => 'Ce site est d&eacute;j&agrave; enregistr&eacute;',
'form_pet_url_invalide' => 'L\'URL que vous avez indiqu&eacute;e n\'est pas valide.',
'form_pet_votre_email' => 'Votre adresse email',
'form_pet_votre_nom' => 'Votre nom ou pseudo',
'form_pet_votre_site' => 'Si vous avez un site Web, vous pouvez l\'indiquer ci-dessous',
'form_prop_confirmer_envoi' => 'Confirmer l\'envoi',
'form_prop_description' => 'Description/commentaire',
'form_prop_enregistre' => 'Votre proposition est enregistr&eacute;e, elle appara&icirc;tra en ligne apr&egrave;s validation par les responsables de ce site.',
'form_prop_envoyer' => 'Envoyer un message',
'form_prop_indiquer_email' => 'Veuillez indiquer une adresse email valide',
'form_prop_indiquer_nom_site' => 'Veuillez indiquer le nom du site.',
'form_prop_indiquer_sujet' => 'Veuillez indiquer un sujet',
'form_prop_message_envoye' => 'Message envoy&eacute;',
'form_prop_nom_site' => 'Nom du site',
'form_prop_non_enregistre' => 'Votre proposition n\'a pas &eacute;t&eacute; enregistr&eacute;e.',
'form_prop_sujet' => 'Sujet',
'form_prop_url_site' => 'Adresse (URL) du site',
'forum_acces_refuse' => 'Vous n\'avez plus acc&egrave;s &agrave; ces forums.',
'forum_attention_dix_caracteres' => '<b>Attention&nbsp;!</b> votre message doit contenir au moins dix caract&egrave;res.',
'forum_attention_trois_caracteres' => '<b>Attention&nbsp;!</b> votre titre doit contenir au moins trois caract&egrave;res.',
'forum_attention_trop_caracteres' => '<b>Attention&nbsp;!</b> votre message est trop long (@compte@ caract&egrave;res)&nbsp;: pour pouvoir &ecirc;tre enregistr&eacute;, il ne doit pas d&eacute;passer @max@ caract&egrave;res.',
'forum_avez_selectionne' => 'Vous avez s&eacute;lectionn&eacute;&nbsp;:',
'forum_cliquer_retour' => 'Cliquez <a href=\'@retour_forum@\'>ici</a> pour continuer.',
'forum_forum' => 'forum',
'forum_info_modere' => 'Ce forum est mod&eacute;r&eacute; &agrave; priori&nbsp;: votre contribution n\'appara&icirc;tra qu\'apr&egrave;s avoir &eacute;t&eacute; valid&eacute;e par un administrateur du site.',
'forum_lien_hyper' => '<b>Lien hypertexte</b> (optionnel)',
'forum_message_definitif' => 'Message d&eacute;finitif : envoyer au site',
'forum_message_trop_long' => 'Votre message est trop long. La taille maximale est de 20000 caract&egrave;res.',
'forum_ne_repondez_pas' => 'Ne r&eacute;pondez pas &agrave; ce mail mais sur le forum &agrave; l\'adresse suivante :',
'forum_non_inscrit' => 'Vous n\'&ecirc;tes pas inscrit, ou l\'adresse ou le mot de passe sont erron&eacute;s.',
'forum_page_url' => '(Si votre message se r&eacute;f&egrave;re &agrave; un article publi&eacute; sur le Web, ou &agrave; une page fournissant plus d\'informations, vous pouvez indiquer ci-apr&egrave;s le titre de la page et son adresse.)',
'forum_par_auteur' => 'par @auteur@',
'forum_poste_par' => 'Message post&eacute;@parauteur@ &agrave; la suite de l\'article &laquo; @titre@ &raquo;.',
'forum_probleme_database' => 'Probl&egrave;me de base de donn&eacute;es, votre message n\'a pas &eacute;t&eacute; enregistr&eacute;.',
'forum_qui_etes_vous' => '<b>Qui &ecirc;tes-vous ?</b> (optionnel)',
'forum_texte' => 'Texte de votre message :',
'forum_titre' => 'Titre :',
'forum_titre_erreur' => 'Erreur...',
'forum_url' => 'URL :',
'forum_valider' => 'Valider ce choix',
'forum_voir_avant' => 'Voir ce message avant de le poster',
'forum_votre_email' => 'Votre adresse email :',
'forum_votre_nom' => 'Votre nom (ou pseudonyme) :',
'forum_vous_enregistrer' => 'Pour participer &agrave;
		ce forum, vous devez vous enregistrer au pr&eacute;alable. Merci
		d\'indiquer ci-dessous l\'identifiant personnel qui vous a
		&eacute;t&eacute; fourni. Si vous n\'&ecirc;tes pas enregistr&eacute;, vous devez',
'forum_vous_inscrire' => 'vous inscrire.',

// I
'ical_texte_rss_articles' => 'Le fichier &laquo;backend&raquo; des articles de ce site se trouve &agrave; l\'adresse:',
'ical_texte_rss_articles2' => 'Vous pouvez &eacute;galement obtenir des fichiers &laquo;backend&raquo; pour les articles de chaque rubrique du site:',
'ical_texte_rss_breves' => 'Il existe de plus un fichier contenant les br&egrave;ves du site. En pr&eacute;cisant un num&eacute;ro de rubrique, vous obtiendrez uniquement les br&egrave;ves de cette rubrique.',
'icone_a_suivre' => '&Agrave; suivre',
'icone_admin_site' => 'Administration du site',
'icone_agenda' => 'Agenda',
'icone_aide_ligne' => 'Aide',
'icone_articles' => 'Articles',
'icone_auteurs' => 'Auteurs',
'icone_breves' => 'Br&egrave;ves',
'icone_brouteur' => 'Navigation rapide',
'icone_configuration_site' => 'Configuration',
'icone_configurer_site' => 'Configurer votre site',
'icone_creer_nouvel_auteur' => 'Cr&eacute;er un nouvel auteur',
'icone_creer_rubrique' => 'Cr&eacute;er une rubrique',
'icone_creer_sous_rubrique' => 'Cr&eacute;er une sous-rubrique',
'icone_deconnecter' => 'Se d&eacute;connecter',
'icone_discussions' => 'Discussions',
'icone_doc_rubrique' => 'Documents des rubriques',
'icone_ecrire_article' => '&Eacute;crire un nouvel article',
'icone_edition_site' => '&Eacute;dition',
'icone_forum_administrateur' => 'Forum des administrateurs',
'icone_forum_suivi' => 'Suivi des forums',
'icone_gestion_langues' => 'Gestion des langues',
'icone_informations_personnelles' => 'Informations personnelles',
'icone_interface_complet' => 'interface compl&egrave;te',
'icone_interface_simple' => 'Interface simplifi&eacute;e',
'icone_maintenance_site' => 'Maintenance du site',
'icone_messagerie_personnelle' => 'Messagerie personnelle',
'icone_mots_cles' => 'Mots-cl&eacute;s',
'icone_nouvelle_breve' => '&Eacute;crire une nouvelle br&egrave;ve',
'icone_repartition_actuelle' => 'Afficher la r&eacute;partition actuelle',
'icone_repartition_debut' => 'Afficher la r&eacute;partition depuis le d&eacute;but',
'icone_repartition_visites' => 'R&eacute;partition des visites',
'icone_rubriques' => 'Rubriques',
'icone_sauver_site' => 'Sauvegarde du site',
'icone_site_entier' => 'Tout le site',
'icone_sites_references' => 'Sites r&eacute;f&eacute;renc&eacute;s',
'icone_statistiques' => 'Statistiques du site',
'icone_statistiques_visites' => 'Statistiques',
'icone_suivi_activite' => 'Suivre la vie du site',
'icone_suivi_actualite' => '&Eacute;volution du&nbsp;site',
'icone_suivi_forums' => 'Suivre/g&eacute;rer les forums',
'icone_suivi_pettions' => 'Suivre/g&eacute;rer les p&eacute;titions',
'icone_suivi_revisions' => 'Modifications des articles',
'icone_supprimer_document' => 'Supprimer ce document',
'icone_supprimer_image' => 'Supprimer cette image',
'icone_supprimer_message' => 'Supprimer ce message',
'icone_tous_articles' => 'Tous vos articles',
'icone_tous_auteur' => 'Tous les auteurs',
'icone_valider_message' => 'Valider ce message',
'icone_visiter_site' => 'Visiter',
'icone_voir_en_ligne' => 'Voir en ligne',
'image_tourner_180' => 'Rotation 180&deg;',
'image_tourner_droite' => 'Rotation 90&deg; &agrave; droite',
'image_tourner_gauche' => 'Rotation 90&deg; &agrave; gauche',
'img_indisponible' => 'image indisponible',
'impossible' => 'impossible',
'info_a_suivre' => '&Agrave; SUIVRE&nbsp;&raquo;',
'info_a_valider' => '[&agrave; valider]',
'info_acces_interdit' => 'Acc&egrave;s interdit',
'info_acces_refuse' => 'Acc&egrave;s refus&eacute;',
'info_action' => 'Action : @action@',
'info_administrer_rubriques' => 'Vous pouvez administrer cette rubrique et ses sous-rubriques',
'info_adresse_non_indiquee' => 'Vous n\'avez pas indiqu&eacute; d\'adresse &agrave; tester&nbsp;!',
'info_aide' => 'AIDE :',
'info_ajouter_mot' => 'Ajouter ce mot',
'info_annonce' => 'ANNONCE',
'info_annonces_generales' => 'Annonces g&eacute;n&eacute;rales&nbsp;:',
'info_article_propose' => 'Article propos&eacute;',
'info_article_publie' => 'Article publi&eacute;',
'info_article_redaction' => 'Article en cours de r&eacute;daction',
'info_article_refuse' => 'Article refus&eacute;',
'info_article_supprime' => 'Article supprim&eacute;',
'info_articles' => 'Articles',
'info_articles_a_valider' => 'Les articles &agrave; valider',
'info_articles_nb' => '@nb@ articles',
'info_articles_proposes' => 'Articles propos&eacute;s',
'info_articles_un' => '1 article',
'info_auteurs_nombre' => 'auteur(s)&nbsp;:',
'info_authentification_ftp' => 'Authentification (par FTP).',
'info_bloquer_lien' => 'bloquer ce lien',
'info_breves_02' => 'Br&egrave;ves',
'info_breves_2' => 'br&egrave;ves',
'info_breves_nb' => '@nb@ br&egrave;ves',
'info_breves_un' => '1 br&egrave;ve',
'info_breves_valider' => 'Br&egrave;ves &agrave; valider',
'info_connexion_refusee' => 'Connexion refus&eacute;e',
'info_contact_developpeur' => 'Veuillez contacter un developpeur.',
'info_contenance' => 'Ce site contient&nbsp;:',
'info_contribution' => 'contributions de forum',
'info_copyright' => '@spip@ est un logiciel libre distribu&eacute; @lien_gpl@.',
'info_copyright_doc' => 'Pour plus d\'informations, voir le site <a href="@spipnet@">http://www.spip.net/fr</a>.',
'info_copyright_gpl' => 'sous licence GPL',
'info_cours_edition' => 'Vos articles en cours de r&eacute;daction',
'info_creer_repertoire' => 'Veuillez cr&eacute;er un fichier ou un r&eacute;pertoire nomm&eacute;&nbsp;:',
'info_creer_repertoire_2' => '&agrave; l\'int&eacute;rieur du sous-r&eacute;pertoire <b>@repertoire@</b>, puis&nbsp;:',
'info_creer_vignette' => 'cr&eacute;ation automatique de la vignette',
'info_deplier' => 'D&eacute;plier',
'info_descriptif_nombre' => 'descriptif(s)&nbsp;:',
'info_description' => 'Description&nbsp;:',
'info_description_2' => 'Description&nbsp;:',
'info_dimension' => 'Dimensions&nbsp;:',
'info_document' => 'Document',
'info_document_indisponible' => 'Ce document n\'est pas disponible',
'info_documents' => 'Documents',
'info_documents_nb' => '@nb@ documents',
'info_documents_un' => '1 document',
'info_echange_message' => 'SPIP permet l\'&eacute;change de messages et la constitution de forums de discussion
		priv&eacute;s entre les participants du site. Vous pouvez activer ou
		d&eacute;sactiver cette fonctionnalit&eacute;.',
'info_ecire_message_prive' => 'Ecrire un message priv&eacute;',
'info_email_invalide' => 'Adresse email invalide.',
'info_en_cours_validation' => 'Vos articles en cours de r&eacute;daction',
'info_en_ligne' => 'Actuellement en ligne&nbsp;:',
'info_envoyer_message_prive' => 'Envoyer un message priv&eacute; &agrave; cet auteur',
'info_erreur_requete' => 'Erreur dans la requ&ecirc;te :',
'info_erreur_squelette2' => 'Aucun squelette <b>@fichier@</b> n\'est disponible...',
'info_erreur_systeme' => 'Erreur syst&egrave;me (errno @errsys@)',
'info_erreur_systeme2' => 'Le disque dur est peut-&ecirc;tre plein, ou la base de donn&eacute;es endommag&eacute;e. <br />
	<font color=\'red\'>Essayez de <a href=\'@script@\'>r&eacute;parer la base</a>,
	ou contactez votre h&eacute;bergeur.</font>',
'info_fini' => 'C\'est fini !',
'info_format_image' => 'Formats d\'images pouvant &ecirc;tre utilis&eacute;es pour cr&eacute;er des vignettes&nbsp;: @gd_formats@.',
'info_format_non_defini' => 'format non d&eacute;fini',
'info_grand_ecran' => 'Grand &eacute;cran',
'info_image_aide' => 'AIDE',
'info_image_process_titre' => 'M&eacute;thode de fabrication des vignettes',
'info_impossible_lire_page' => '<b>Erreur !</b> Impossible de lire la page <tt><html>@test_proxy@</html></tt> &agrave; travers le proxy ',
'info_inclusion_directe' => 'Inclusion directe&nbsp;:',
'info_inclusion_vignette' => 'Inclusion de la vignette&nbsp;:',
'info_installation_systeme_publication' => 'Installation du syst&egrave;me de publication...',
'info_installer_documents' => 'Vous pouvez installer automatiquement tous les documents contenus dans le dossier @upload@.',
'info_installer_ftp' => 'En tant qu\'administrateur, vous pouvez installer (par FTP) des fichiers dans le dossier @upload@ pour ensuite les s&eacute;lectionner directement ici.',
'info_installer_images' => 'Vous pouvez installer des images aux formats JPEG, GIF et PNG.',
'info_installer_images_dossier' => 'Installer des images dans le dossier @upload@ pour pouvoir les s&eacute;lectionner ici.',
'info_installer_tous_documents' => 'Installer tous les documents',
'info_interface_complete' => 'interface compl&egrave;te',
'info_interface_simple' => 'Interface simplifi&eacute;e',
'info_joindre_document_article' => 'Vous pouvez joindre &agrave; cet article des documents de type',
'info_joindre_document_rubrique' => 'Vous pouvez ajouter dans cette rubrique des documents de type',
'info_joindre_documents_article' => 'Vous pouvez joindre &agrave; votre article des documents de type&nbsp;:',
'info_l_article' => 'l\'article',
'info_la_breve' => 'la br&egrave;ve',
'info_la_rubrique' => 'la rubrique',
'info_langue_principale' => 'Langue principale du site',
'info_largeur_vignette' => '@largeur_vignette@ &#215; @hauteur_vignette@ pixels',
'info_les_auteurs_1' => 'par @les_auteurs@',
'info_logo_format_interdit' => 'Seuls les logos aux formats @formats@ sont autoris&eacute;s.',
'info_logo_max_poids' => 'Les logos doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
'info_logo_max_taille' => 'Les logos doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
'info_mail_fournisseur' => 'vous@fournisseur.com',
'info_message_2' => 'MESSAGE',
'info_message_supprime' => 'MESSAGE SUPPRIM&Eacute;',
'info_messages_nb' => '@nb@ messages',
'info_messages_un' => '1 message',
'info_mise_en_ligne' => 'Date de mise en ligne&nbsp;:',
'info_modification_parametres_securite' => 'modifications des param&egrave;tres de s&eacute;curit&eacute;',
'info_mois_courant' => 'Dans le courant du mois :',
'info_mot_cle_ajoute' => 'Le mot-cl&eacute; suivant a &eacute;t&eacute; ajout&eacute; &agrave;',
'info_multi_herit' => 'Langue par d&eacute;faut',
'info_multi_langues_soulignees' => 'Les <u>langues soulign&eacute;es</u> b&eacute;n&eacute;ficient d\'une traduction de tous les textes de l\'interface. Si vous s&eacute;lectionnez ces langues, de nombreux &eacute;l&eacute;ments du site public (dates, formulaires) seront automatiquement traduits. Pour les langues non soulign&eacute;es, ces &eacute;l&eacute;ments appara&icirc;tront dans la langue principale du site.',
'info_multilinguisme' => 'Multilinguisme',
'info_nom_non_utilisateurs_connectes' => 'Votre nom n\'appara&icirc;t pas dans la liste des utilisateurs connect&eacute;s.',
'info_nom_utilisateurs_connectes' => 'Votre nom appara&icirc;t dans la liste des utilisateurs connect&eacute;s.',
'info_nombre_en_ligne' => 'Actuellement en ligne&nbsp;:',
'info_non_resultat' => 'Aucun r&eacute;sultat pour "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Vous n\'utilisez pas la messagerie interne de ce site.',
'info_nouveau_message' => 'VOUS AVEZ UN NOUVEAU MESSAGE',
'info_nouveaux_messages' => 'VOUS AVEZ @total_messages@ NOUVEAUX MESSAGES',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Cette information est obligatoire',
'info_panne_site_syndique' => 'Site syndiqu&eacute; en panne',
'info_pense_bete' => 'PENSE-B&Ecirc;TE',
'info_petit_ecran' => 'Petit &eacute;cran',
'info_petition_close' => 'P&eacute;tition close',
'info_pixels' => 'pixels',
'info_plusieurs_mots_trouves' => 'Plusieurs mots-cl&eacute;s trouv&eacute;s pour "@cherche_mot@":',
'info_popularite_5' => 'popularit&eacute;&nbsp;:',
'info_portfolio' => 'Portfolio',
'info_portfolio_automatique' => 'Portfolio automatique&nbsp;:',
'info_premier_resultat' => '[@debut_limit@ premiers r&eacute;sultats sur @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ premiers r&eacute;sultats sur @total@]',
'info_probleme_grave' => 'probl&egrave;me de',
'info_propose_1' => '[@nom_site_spip@] Propose : @titre@',
'info_propose_2' => 'Article propos&eacute;
---------------',
'info_propose_3' => 'L\'article "@titre@" est propos&eacute; &agrave; la publication.',
'info_propose_4' => 'Vous &ecirc;tes invit&eacute; &agrave; venir le consulter et &agrave; donner votre opinion',
'info_propose_5' => 'dans le forum qui lui est attach&eacute;. Il est disponible &agrave; l\'adresse :',
'info_publie_01' => 'L\'article "@titre@" a &eacute;t&eacute; valid&eacute; par @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLIE : @titre@',
'info_publie_2' => 'Article publi&eacute;
--------------',
'info_rechercher' => 'Rechercher',
'info_rechercher_02' => 'Rechercher&nbsp;:',
'info_remplacer_vignette' => 'Remplacer la vignette par d&eacute;faut par un logo personnalis&eacute;&nbsp;:',
'info_retablir_lien' => 'r&eacute;tablir ce lien',
'info_retirer_mot' => 'Retirer ce mot',
'info_retirer_mots' => 'Retirer tous les mots',
'info_rubriques_nb' => '@nb@ rubriques',
'info_rubriques_un' => '1 rubrique',
'info_sans_titre_2' => 'sans titre',
'info_selectionner_fichier' => 'Vous pouvez s&eacute;lectionner un fichier du dossier @upload@',
'info_selectionner_fichier_2' => 'S&eacute;lectionner un fichier&nbsp;:',
'info_signature_supprimee' => 'Signature supprim&eacute;e',
'info_signature_supprimee_erreur' => 'Erreur&nbsp;: ce code de suppression ne correspond a aucune signature',
'info_site_attente' => 'Site Web en attente de validation',
'info_site_reference' => 'Site r&eacute;f&eacute;renc&eacute; en ligne',
'info_site_refuse' => 'Site Web refus&eacute;',
'info_sites_nb' => '@nb@ sites',
'info_sites_referencer' => 'R&eacute;f&eacute;rencer un site',
'info_sites_un' => '1 site',
'info_supprimer_vignette' => 'supprimer la vignette',
'info_symbole_bleu' => 'Le symbole <b>bleu</b> indique un <b>pense-b&ecirc;te</b>: c\'est-&agrave;-dire un message &agrave; votre usage personnel.',
'info_symbole_jaune' => 'Le symbole <b>jaune</b> indique une <b>annonce &agrave; tous les r&eacute;dacteurs</b>&nbsp;: modifiable par tous les administrateurs, et visible par tous les r&eacute;dacteurs.',
'info_symbole_vert' => 'Le symbole <b>vert</b> indique les <b>messages &eacute;chang&eacute;s avec d\'autres utilisateurs</b> du site.',
'info_syndication' => 'syndication&nbsp;:',
'info_syndication_articles' => 'article(s)',
'info_telecharger' => 'T&eacute;l&eacute;charger depuis votre ordinateur&nbsp;:',
'info_telecharger_nouveau_logo' => 'T&eacute;l&eacute;charger un nouveau logo&nbsp;:',
'info_telecharger_ordinateur' => 'T&eacute;l&eacute;charger depuis votre ordinateur&nbsp;:',
'info_tous_resultats_enregistres' => '[tous les r&eacute;sultats sont enregistr&eacute;s]',
'info_tout_afficher' => 'Tout afficher',
'info_travaux_texte' => 'Ce site n\'est pas encore configur&eacute;. Revenez plus tard...',
'info_travaux_titre' => 'Site en travaux',
'info_trop_resultat' => 'Trop de r&eacute;sultats pour "@cherche_mot@" ; veuillez affiner la recherche.',
'info_utilisation_messagerie_interne' => 'Vous utilisez la messagerie interne de ce site.',
'info_valider_lien' => 'valider ce lien',
'info_verifier_image' => ', veuillez v&eacute;rifier que vos images ont &eacute;t&eacute; transf&eacute;r&eacute;es correctement.',
'info_vignette_defaut' => 'Vignette par d&eacute;faut',
'info_vignette_personnalisee' => 'Vignette personnalis&eacute;e',
'info_visite' => 'visite :',
'info_visites' => 'visites :',
'info_vos_rendez_vous' => 'Vos rendez-vous &agrave; venir',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Vos pense-b&ecirc;tes',
'item_breve_proposee' => 'Br&egrave;ve propos&eacute;e',

// L
'lien_afficher_icones_seuls' => 'Afficher uniquement les icones',
'lien_afficher_texte_icones' => 'Afficher les icones et le texte',
'lien_afficher_texte_seul' => 'Afficher uniquement le texte',
'lien_liberer' => 'lib&eacute;rer',
'lien_liberer_tous' => 'lib&eacute;rer ces articles',
'lien_nouvea_pense_bete' => 'NOUVEAU PENSE-B&Ecirc;TE',
'lien_nouveau_message' => 'NOUVEAU MESSAGE',
'lien_nouvelle_annonce' => 'NOUVELLE ANNONCE',
'lien_petitions' => 'P&Eacute;TITION',
'lien_popularite' => 'popularit&eacute;&nbsp;: @popularite@%',
'lien_racine_site' => 'RACINE DU SITE',
'lien_reessayer' => 'r&eacute;essayer',
'lien_repondre_message' => 'R&eacute;pondre &agrave; ce message',
'lien_supprimer' => 'supprimer',
'lien_tout_afficher' => 'Tout afficher',
'lien_visite_site' => 'visiter ce site',
'lien_visites' => '@visites@&nbsp;visites',
'lien_voir_auteur' => 'Voir cet auteur',
'ligne' => 'Ligne',
'login' => 'Connexion',
'login_acces_prive' => 'acc&egrave;s &agrave; l\'espace priv&eacute;',
'login_autre_identifiant' => 'se connecter sous un autre identifiant',
'login_cookie_accepte' => 'Veuillez r&eacute;gler votre navigateur pour qu\'il les accepte (au moins pour ce site).',
'login_cookie_oblige' => 'Pour vous identifier de fa&ccedil;on s&ucirc;re sur ce site, vous devez accepter les cookies.',
'login_deconnexion_ok' => 'D&eacute;connexion effectu&eacute;e.',
'login_erreur_pass' => 'Erreur de mot de passe.',
'login_espace_prive' => 'espace priv&eacute;',
'login_identifiant_inconnu' => 'L\'identifiant &laquo; @login@ &raquo; est inconnu.',
'login_login' => 'Login :',
'login_login2' => 'Login (identifiant de connexion au site)&nbsp;:',
'login_login_pass_incorrect' => '(Login ou mot de passe incorrect.)',
'login_motpasseoublie' => 'mot&nbsp;de&nbsp;passe&nbsp;oubli&eacute;&nbsp;?',
'login_non_securise' => 'Attention, ce formulaire n\'est pas s&eacute;curis&eacute;.
			Si vous ne voulez pas que votre mot de passe puisse &ecirc;tre
			intercept&eacute; sur le r&eacute;seau, veuillez activer Javascript
			dans votre navigateur et',
'login_nouvelle_tentative' => 'Nouvelle tentative',
'login_par_ici' => 'Vous &ecirc;tes enregistr&eacute;... par ici...',
'login_pass2' => 'Mot de passe&nbsp;:',
'login_preferez_refuser' => '<b>Si vous pr&eacute;f&eacute;rez refuser les cookies</b>, une autre m&eacute;thode de connexion (moins s&eacute;curis&eacute;e) est &agrave; votre disposition&nbsp;:',
'login_recharger' => 'recharger cette page',
'login_rester_identifie' => 'Rester identifi&eacute; quelques jours',
'login_retour_public' => 'Retour au site public',
'login_retour_site' => 'Retour au site public',
'login_retoursitepublic' => 'retour&nbsp;au&nbsp;site&nbsp;public',
'login_sans_cookiie' => 'Identification sans cookie',
'login_securise' => 'Login s&eacute;curis&eacute;',
'login_sinscrire' => 's\'inscrire',
'login_test_navigateur' => 'test navigateur/reconnexion',
'login_verifiez_navigateur' => '(V&eacute;rifiez toutefois que votre navigateur n\'a pas m&eacute;moris&eacute; votre mot de passe...)',

// M
'masquer_colonne' => 'Masquer cette colonne',
'masquer_trad' => 'masquer les traductions',
'module_fichiers_langues' => 'Fichiers de langue',

// N
'navigateur_pas_redirige' => 'Si votre navigateur n\'est pas redirig&eacute;, cliquez ici pour continuer.',
'numero' => 'Num&eacute;ro',

// O
'occurence' => 'Occurrence',
'onglet_affacer_base' => 'Effacer la base',
'onglet_auteur' => 'L\'auteur',
'onglet_contenu_site' => 'Contenu du site',
'onglet_evolution_visite_mod' => '&Eacute;volution',
'onglet_fonctions_avances' => 'Fonctions avanc&eacute;es',
'onglet_informations_personnelles' => 'Informations personnelles',
'onglet_interactivite' => 'Interactivit&eacute;',
'onglet_messagerie' => 'Messagerie',
'onglet_messages_internes' => 'Messages internes',
'onglet_messages_publics' => 'Messages publics',
'onglet_messages_vide' => 'Messages sans texte',
'onglet_origine_visites' => 'Origine des visites',
'onglet_repartition_debut' => 'depuis le d&eacute;but',
'onglet_repartition_lang' => 'R&eacute;partition par langues',
'onglet_repartition_rubrique' => 'R&eacute;partition par rubriques',
'onglet_save_restaur_base' => 'Sauvegarder/restaurer la base',
'onglet_vider_cache' => 'Vider le cache',

// P
'pass_choix_pass' => 'Veuillez choisir votre nouveau mot de passe :',
'pass_erreur' => 'Erreur',
'pass_erreur_acces_refuse' => '<b>Erreur :</b> vous n\'avez plus acc&egrave;s &agrave; ce site.',
'pass_erreur_code_inconnu' => '<b>Erreur :</b> ce code ne correspond &agrave; aucun des visiteurs ayant acc&egrave;s &agrave; ce site.',
'pass_erreur_non_enregistre' => '<b>Erreur :</b> l\'adresse <tt>@email_oubli@</tt> n\'est pas enregistr&eacute;e sur ce site.',
'pass_erreur_non_valide' => '<b>Erreur :</b> cet email <tt>@email_oubli@</tt> n\'est pas valide !',
'pass_erreur_probleme_technique' => '<b>Erreur :</b> &agrave; cause d\'un probl&egrave;me technique, l\'email ne peut pas &ecirc;tre envoy&eacute;.',
'pass_espace_prive_bla' => 'L\'espace priv&eacute; de ce site est ouvert aux
		visiteurs, apr&egrave;s inscription. Une fois enregistr&eacute;,
		vous pourrez consulter les articles en cours de r&eacute;daction,
		proposer des articles et participer &agrave; tous les forums.',
'pass_forum_bla' => 'Vous avez demand&eacute; &agrave; intervenir sur un forum
		r&eacute;serv&eacute; aux visiteurs enregistr&eacute;s.',
'pass_indiquez_cidessous' => 'Indiquez ci-dessous l\'adresse email sous laquelle vous
			vous &ecirc;tes pr&eacute;c&eacute;demment enregistr&eacute;. Vous
			recevrez un email vous indiquant la marche &agrave; suivre pour
			r&eacute;cup&eacute;rer votre acc&egrave;s.',
'pass_mail_passcookie' => '(ceci est un message automatique)
Pour retrouver votre acc&egrave;s au site
@nom_site_spip@ (@adresse_site@)

Veuillez vous rendre &agrave; l\'adresse suivante :

    @sendcookie@

Vous pourrez alors entrer un nouveau mot de passe
et vous reconnecter au site.

',
'pass_mot_oublie' => 'Mot de passe oubli&eacute;',
'pass_nouveau_enregistre' => 'Votre nouveau mot de passe a &eacute;t&eacute; enregistr&eacute;.',
'pass_nouveau_pass' => 'Nouveau mot de passe',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Oubli du mot de passe',
'pass_quitter_fenetre' => 'Quitter cette fen&ecirc;tre',
'pass_rappel_login' => 'Rappel : votre identifiant (login) est &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Vous allez recevoir un email vous indiquant comment retrouver votre acc&egrave;s au site.',
'pass_retour_public' => 'Retour sur le site public',
'pass_rien_a_faire_ici' => 'Rien &agrave; faire ici.',
'pass_vousinscrire' => 'Vous inscrire sur ce site',
'precedent' => 'pr&eacute;c&eacute;dent',
'previsualisation' => 'Pr&eacute;visualisation',
'previsualiser' => 'Pr&eacute;visualiser',

// R
'retour' => 'Retour',

// S
'spip_conforme_dtd' => 'SPIP consid&egrave;re ce document comme conforme &agrave; son DOCTYPE :',
'squelette' => 'squelette',
'squelette_inclus_ligne' => 'squelette inclus, ligne',
'squelette_ligne' => 'squelette, ligne',
'stats_visites_et_popularite' => '@visites@ visites&nbsp;; popularit&eacute;&nbsp;: @popularite@',
'suivant' => 'suivant',

// T
'taille_ko' => '@taille@&nbsp;ko',
'taille_mo' => '@taille@&nbsp;Mo',
'taille_octets' => '@taille@&nbsp;octets',
'texte_actualite_site_1' => 'Quand vous serez familiaris&eacute;(e) avec l\'interface, vous pourrez cliquer sur &laquo;',
'texte_actualite_site_2' => 'interface compl&egrave;te',
'texte_actualite_site_3' => '&raquo; pour ouvrir plus de possibilit&eacute;s.',
'texte_creation_automatique_vignette' => 'La cr&eacute;ation automatique de vignettes de pr&eacute;visualisation est activ&eacute;e sur ce site. Si vous installez &agrave; partir de ce formulaire des images au(x) format(s) @gd_formats@, elles seront accompagn&eacute;es d\'une vignette d\'une taille maximale de @taille_preview@&nbsp;pixels.',
'texte_documents_associes' => 'Les documents suivants sont associ&eacute;s &agrave; l\'article,
				mais ils n\'y ont pas &eacute;t&eacute; directement
				ins&eacute;r&eacute;s. Selon la mise en page du site public,
				ils pourront appara&icirc;tre sous forme de documents joints.',
'texte_erreur_mise_niveau_base' => 'Erreur de base de donn&eacute;es lors de la mise &agrave; niveau.
		L\'image <b>@fichier@</b> n\'est pas pass&eacute;e (article @id_article@).
		Notez bien cette r&eacute;f&eacute;rence, r&eacute;essayez la mise &agrave;
		niveau, et enfin v&eacute;rifiez que les images apparaissent
		toujours dans les articles.',
'texte_erreur_visiteur' => 'Vous avez tent&eacute; d\'acc&eacute;der &agrave; l\'espace priv&eacute; avec un login qui ne le permet pas.',
'texte_inc_auth_1' => 'Vous &ecirc;tes identifi&eacute; sous le
		login <b>@auth_login@</b>, mais celui-ci n\'existe pas/plus dans la base.
		Essayez de vous',
'texte_inc_auth_2' => 'reconnecter',
'texte_inc_auth_3' => ', apr&egrave;s avoir &eacute;ventuellement quitt&eacute; puis
		red&eacute;marr&eacute; votre navigateur.',
'texte_inc_config' => 'Les modifications effectu&eacute;es dans ces pages influent notablement sur le
 fonctionnement de votre site. Nous vous recommandons de ne pas y intervenir tant que vous n\'&ecirc;tes pas
 familier du fonctionnement du syst&egrave;me SPIP. <br /><br /><b>Plus
 g&eacute;n&eacute;ralement, il est fortement conseill&eacute;
 de laisser la charge de ces pages au webmestre principal de votre site.</b>',
'texte_inc_meta_1' => 'Le syst&egrave;me a rencontr&eacute; une erreur lors de l\'&eacute;criture du fichier <code>@fichier@</code>. Veuillez, en tant qu\'administrateur du site,',
'texte_inc_meta_2' => 'v&eacute;rifier les droits d\'&eacute;criture',
'texte_inc_meta_3' => 'sur le r&eacute;pertoire <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'en cours de r&eacute;daction',
'texte_statut_poubelle' => '&agrave; la poubelle',
'texte_statut_propose_evaluation' => 'propos&eacute; &agrave; l\'&eacute;valuation',
'texte_statut_publie' => 'publi&eacute; en ligne',
'texte_statut_refuse' => 'refus&eacute;',
'titre_ajouter_mot_cle' => 'AJOUTER UN MOT-CL&Eacute; :',
'titre_breve_proposee' => 'Br&egrave;ve propos&eacute;e',
'titre_breve_publiee' => 'Br&egrave;ve publi&eacute;e',
'titre_breve_refusee' => 'Br&egrave;ve refus&eacute;e',
'titre_cadre_raccourcis' => 'RACCOURCIS :',
'titre_changer_couleur_interface' => 'Changer la couleur de l\'interface',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Vous pouvez administrer cet article',
'titre_image_administrateur' => 'Administrateur',
'titre_image_aide' => 'De l\'aide sur cet &eacute;l&eacute;ment',
'titre_image_auteur_supprime' => 'Auteur supprim&eacute;',
'titre_image_redacteur' => 'R&eacute;dacteur sans acc&egrave;s',
'titre_image_redacteur_02' => 'R&eacute;dacteur',
'titre_image_visiteur' => 'Visiteur',
'titre_joindre_document' => 'JOINDRE UN DOCUMENT',
'titre_liens_entrants' => 'Liens entrants',
'titre_mots_cles' => 'MOTS-CL&Eacute;S',
'titre_probleme_technique' => 'Attention&nbsp;: un probl&egrave;me technique (serveur SQL) emp&ecirc;che l\'acc&egrave;s &agrave; cette partie du site. Merci de votre compr&eacute;hension.',
'titre_publier_document' => 'PUBLIER UN DOCUMENT DANS CETTE RUBRIQUE',
'titre_signatures_attente' => 'Signatures en attente de validation',
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es',
'titre_statistiques' => 'Statistiques du site',
'titre_titre_document' => 'Titre du document&nbsp;:',
'todo' => '&agrave; venir',
'trad_reference' => '(article de r&eacute;f&eacute;rence)',

// Z
'zbug_balise_b_aval' => '&nbsp;: balise B en aval',
'zbug_balise_inexistante' => 'Balise @balise@ mal d&eacute;clar&eacute;e pour @from@',
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@',
'zbug_boucle' => 'boucle',
'zbug_boucle_recursive_undef' => 'Boucle r&eacute;cursive non d&eacute;finie&nbsp;: @nom@',
'zbug_calcul' => 'calcul',
'zbug_champ_hors_boucle' => 'Champ @champ@ hors boucle',
'zbug_champ_hors_motif' => 'Champ @champ@ hors d\'un contexte @motif@',
'zbug_code' => 'code',
'zbug_critere_inconnu' => 'Crit&egrave;re inconnu @critere@',
'zbug_distant_interdit' => 'Externe interdit', # Contexte : une base de donn&eacute;es "externe", pas g&eacute;r&eacute;e par SPIP, mais que SPIP 1.8 sait utiliser dans ses boucles -- seul probl&egrave;mes certaines manipulations sont interdites sur ces bases-l&agrave;.
'zbug_doublon_table_sans_cle_primaire' => 'Doublons sur une table sans clef primaire atomique',
'zbug_doublon_table_sans_index' => 'Doublons sur une table sans index',
'zbug_erreur_boucle_double' => 'Double d&eacute;finition de la boucle @id@',
'zbug_erreur_boucle_fermant' => 'Boucle @id@ non ferm&eacute;e',
'zbug_erreur_boucle_syntaxe' => 'Syntaxe de la boucle @id@ incorrecte',
'zbug_erreur_compilation' => 'Erreur de compilation',
'zbug_erreur_execution_page' => 'Erreur d\'ex&eacute;cution',
'zbug_erreur_filtre' => 'Filtre @filtre@ non d&eacute;fini',
'zbug_erreur_meme_parent' => 'Le crit&egrave;re {meme_parent} ne s\'applique qu\'aux boucles (FORUMS) ou (RUBRIQUES)',
'zbug_erreur_squelette' => 'Erreur(s) dans le squelette',
'zbug_hors_compilation' => 'Hors Compilation',
'zbug_info_erreur_squelette' => 'Erreur sur le site',
'zbug_inversion_ordre_inexistant' => 'Inversion d\'un ordre inexistant',
'zbug_pagination_sans_critere' => 'Balise #PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive',
'zbug_parametres_inclus_incorrects' => 'Param&egrave;tre d\'inclusion incorrect&nbsp;: @param@',
'zbug_profile' => 'Temps de calcul&nbsp;: @time@',
'zbug_resultat' => 'r&eacute;sultat',
'zbug_serveur_indefini' => 'Serveur SQL ind&eacute;fini',
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e',
'zbug_table_inconnue' => 'Table SQL &laquo; @table@ &raquo; inconnue',
'zxml_connus_attributs' => 'attributs connus',
'zxml_de' => 'de',
'zxml_inconnu_attribut' => 'attribut inconnu',
'zxml_inconnu_balise' => 'balise inconnue',
'zxml_inconnu_entite' => 'entit&eacute; inconnue',
'zxml_inconnu_id' => 'ID inconnu',
'zxml_mais_de' => 'mais de',
'zxml_non_conforme' => 'n\'est pas conforme au motif',
'zxml_non_fils' => 'n\'est pas un fils de',
'zxml_nonvide_balise' => 'balise non vide',
'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans',
'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte',
'zxml_survoler' => 'survoler pour voir les corrects',
'zxml_valeur_attribut' => 'valeur de l\'attribut',
'zxml_vide_balise' => 'balise vide',
'zxml_vu' => 'vu auparavant'
);

?>
